return require("packer").startup({
	function(use)
		use("wbthomason/packer.nvim")
		use("nvim-lua/plenary.nvim")
		use("neovim/nvim-lspconfig")
		use({
			"srt0/codescope.nvim",
			config = function()
				require("codescope").setup({
					transparent = false, -- Set to true for transparency
				})
				vim.cmd.colorscheme("codescope")
			end,
		})
		use("Snyssfx/goerr-nvim")
		use({
			"lukas-reineke/indent-blankline.nvim",
			config = function()
				require("ibl").setup()
			end,
		})
		use({
			"rcarriga/nvim-dap-ui",
			requires = { "mfussenegger/nvim-dap", "nvim-neotest/nvim-nio" },
			config = function()
				local dap, dapui = require("dap"), require("dapui")
				dapui.setup()
				dap.listeners.before.attach.dapui_config = function()
					dapui.open()
					vim.cmd(":NvimTreeClose<CR>")
				end
				dap.listeners.before.launch.dapui_config = function()
					dapui.open()
					vim.cmd(":NvimTreeClose<CR>")
				end
				dap.listeners.before.event_terminated.dapui_config = function()
					dapui.close()
					vim.cmd(":NvimTreeOpen<CR>")
				end
				dap.listeners.before.event_exited.dapui_config = function()
					dapui.close()
					vim.cmd(":NvimTreeOpen<CR>")
				end
			end,
		})
		use({
			"leoluz/nvim-dap-go",
			requires = { "mfussenegger/nvim-dap" },
			config = function()
				require("plugins.dap")
			end,
		})
		use({
			"hrsh7th/nvim-cmp",
			requires = {
				"hrsh7th/cmp-nvim-lsp",
				"hrsh7th/cmp-buffer",
				"hrsh7th/cmp-path",
				"hrsh7th/cmp-vsnip",
				"hrsh7th/vim-vsnip",
			},
			config = function()
				require("plugins.cmp")
			end,
		})
		use({
			"nvim-lualine/lualine.nvim",
			config = function()
				require("plugins.lualine")
			end,
		})
		use({
			"nvim-treesitter/nvim-treesitter",
			run = ":TSUpdate",
			config = function()
				require("plugins.treesitter")
			end,
		})
		use({
			"nvim-telescope/telescope.nvim",
			config = function()
				require("plugins.telescope")
			end,
		})
		use({
			"nvim-tree/nvim-tree.lua",
			requires = {
				"nvim-tree/nvim-web-devicons",
			},
			config = function()
				require("plugins.tree")
			end,
		})
		use({
			"stevearc/conform.nvim",
			config = function()
				require("plugins.format")
			end,
		})
		use({
			"mfussenegger/nvim-dap",
			config = function()
				local dap = require("dap")
				-- Общие конфигурации для Go
				dap.configurations.go = {
					{
						type = "go",
						name = "Debug",
						request = "launch",
						program = "${file}",
						showLog = true,
						console = "integratedTerminal",
					},
				}
			end,
		})
		if packer_bootstrap then
			require("packer").sync()
		end
	end,
	config = {
		-- The root has to be a directory named "pack"
		package_root = vim.fn.stdpath("data") .. "/site/pack",
	},
})
